@@ -2,7 +2,7 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.62.1'
+__version__ = '0.62.2'
 
 
 def friendlywiki(environ, start_response):
@@ -22,7 +22,6 @@ def init(config):
     import tiddlywebplugins.status
     import tiddlywebplugins.atom
     import tiddlywebplugins.differ
-    import tiddlywebplugins.twimport
     import tiddlywebplugins.console
     from tiddlyweb.util import merge_config
     from tiddlywebwiki.config import config as twwconfig
@@ -32,7 +31,6 @@ def init(config):
     tiddlywebplugins.status.init(config)
     tiddlywebplugins.atom.init(config)
     tiddlywebplugins.differ.init(config)
-    tiddlywebplugins.twimport.init(config)
     tiddlywebplugins.console.init(config)
 
     if 'selector' in config:
